@@ -20,15 +20,6 @@ if [ "$BSD" ]; then
     export PATH
 fi
 
-case $DIST in
-    centos6|ubuntu14)
-        : ${PYTEST:=/root/.local/bin/pytest}
-        ;;
-    *)
-        : ${PYTEST:=pytest-3}
-        ;;
-esac
-
 export bashcomp_bash=bash
 env
 
@@ -37,6 +28,5 @@ autoreconf -i
 make -j
 
 xvfb-run make distcheck \
-    PYTEST=$PYTEST \
     PYTESTFLAGS="--numprocesses=auto --dist=loadfile" \
     RUNTESTFLAGS="--all --verbose"
