@@ -2,6 +2,6 @@ import pytest
 
 
 class TestGprof:
-    @pytest.mark.complete("gprof --", skipif="! gprof --help &>/dev/null")
+    @pytest.mark.complete("gprof --", require_cmd=True)
     def test_1(self, completion):
         assert completion
