@@ -2,6 +2,6 @@ import pytest
 
 
 class TestLess:
-    @pytest.mark.complete("less --")
+    @pytest.mark.complete("less --", require_longopt=True)
     def test_1(self, completion):
         assert completion
