@@ -3,7 +3,7 @@ import pytest
 
 class TestLvremove:
     @pytest.mark.complete(
-        "lvremove --", skipif="! lvremove --help &>/dev/null"
+        "lvremove --", require_cmd=True, xfail="! lvremove --help &>/dev/null"
     )
     def test_1(self, completion):
         assert completion
